@@ -5,9 +5,10 @@ x2 <- sample(c(NA, 1, 2, 3), 100, replace = TRUE)
 k <- sample(1:100, 100, replace = TRUE)
 lag <- sample(-15:15, 100, replace = TRUE)
 idx <- cumsum(sample(c(1, 2, 3, 4), 100, replace = TRUE))
-sum2 <- function(x) {
-  if (all(is.na(x))) return(NA) else sum(x, na.rm = TRUE)
+sum2 <- function(x, na_rm = TRUE) {
+  if (all(is.na(x))) return(NA) else sum(x, na.rm = na_rm)
 }
+ids <- sample(1:100, 10)
 
 test_that("       |--------]------->", {
   expect_identical(
@@ -19,6 +20,28 @@ test_that("       |--------]------->", {
     sum_run(x2, na_pad = TRUE),
     runner(x2, f = sum2, na_pad = TRUE)
   )
+
+  expect_identical(
+    sum_run(x2, na_rm = FALSE),
+    runner(x2, function(x) sum2(x, na_rm = FALSE))
+  )
+
+
+
+  expect_identical(
+    sum_run(x2)[ids],
+    sum_run(x2, at = seq_along(x2)[ids])
+  )
+
+  expect_identical(
+    sum_run(x2, na_pad = TRUE)[ids],
+    sum_run(x2, at = seq_along(x2)[ids], na_pad = TRUE)
+  )
+
+  expect_identical(
+    sum_run(x2, na_rm = FALSE)[ids],
+    sum_run(x2, at = seq_along(x2)[ids], na_rm = FALSE)
+  )
 })
 
 test_that("   [...|----]---+------->", {
@@ -29,6 +52,16 @@ test_that("   [...|----]---+------->", {
   expect_equal(
     sum_run(x2, lag = 3, na_pad = TRUE),
     runner(x2, lag = 3, f = sum2, na_pad = TRUE))
+
+
+
+  expect_equal(
+    sum_run(x2, lag = 3)[ids],
+    sum_run(x2, lag = 3, at = seq_along(x2)[ids]))
+
+  expect_equal(
+    sum_run(x2, lag = 3, na_pad = TRUE)[ids],
+    sum_run(x2, lag = 3, at = seq_along(x2)[ids], na_pad = TRUE))
 })
 
 test_that("       |--------+---]--->", {
@@ -39,6 +72,15 @@ test_that("       |--------+---]--->", {
   expect_equal(
     sum_run(x2, lag = -3, na_pad = TRUE),
     runner(x2, lag = -3, f = sum2, na_pad = TRUE))
+
+
+  expect_equal(
+    sum_run(x2, lag = -3)[ids],
+    sum_run(x2, lag = -3, at = seq_along(x2)[ids]))
+
+  expect_equal(
+    sum_run(x2, lag = -3, na_pad = TRUE)[ids],
+    sum_run(x2, lag = -3, at = seq_along(x2)[ids], na_pad = TRUE))
 })
 
 test_that("  [...]|--------+------->", {
@@ -50,7 +92,6 @@ test_that("  [...]|--------+------->", {
     sum_run(x2, lag = 100, na_pad = TRUE),
     runner(x2, lag = 100, f = sum2, na_pad = TRUE))
 
-
   expect_equal(
     sum_run(x2, lag = -100),
     runner(x2, lag = -100, f = sum2))
@@ -58,6 +99,24 @@ test_that("  [...]|--------+------->", {
   expect_equal(
     sum_run(x2, lag = -100, na_pad = TRUE),
     runner(x2, lag = -100, f = sum2, na_pad = TRUE))
+
+
+
+  expect_equal(
+    sum_run(x2, lag = 100)[ids],
+    sum_run(x2, lag = 100, at = seq_along(x2)[ids]))
+
+  expect_equal(
+    sum_run(x2, lag = 100, na_pad = TRUE)[ids],
+    sum_run(x2, lag = 100, at = seq_along(x2), na_pad = TRUE)[ids])
+
+  expect_equal(
+    sum_run(x2, lag = -100)[ids],
+    sum_run(x2, lag = -100, at = seq_along(x2)[ids]))
+
+  expect_equal(
+    sum_run(x2, lag = -100, na_pad = TRUE)[ids],
+    sum_run(x2, lag = -100, at = seq_along(x2)[ids], na_pad = TRUE))
 })
 
 test_that("       |----[...]------->", {
@@ -69,6 +128,15 @@ test_that("       |----[...]------->", {
     sum_run(x2, k = 3, na_pad = TRUE),
     runner(x2, k = 3, f = sum2, na_pad = TRUE))
 
+
+  expect_equal(
+    sum_run(x2, k = 3)[ids],
+    sum_run(x2, k = 3, at = seq_along(x2)[ids]))
+
+  expect_equal(
+    sum_run(x2, k = 3, na_pad = TRUE)[ids],
+    sum_run(x2, k = 3, at = seq_along(x2)[ids], na_pad = TRUE))
+
 })
 
 test_that("       [...|--------+-------[...]", {
@@ -95,6 +163,32 @@ test_that("       [...|--------+-------[...]", {
   expect_equal(
     sum_run(x2, k = 100, na_pad = TRUE),
     runner(x2, k = 100, f = sum2, na_pad = TRUE))
+
+
+
+  expect_equal(
+    sum_run(x2, k = 1)[ids],
+    sum_run(x2, k = 1, at = seq_along(x2)[ids]))
+
+  expect_equal(
+    sum_run(x2, k = 1, na_pad = TRUE)[ids],
+    sum_run(x2, k = 1, at = seq_along(x2)[ids], na_pad = TRUE))
+
+  expect_equal(
+    sum_run(x2, k = 99)[ids],
+    sum_run(x2, k = 99, at = seq_along(x2)[ids]))
+
+  expect_equal(
+    sum_run(x2, k = 99, na_pad = TRUE)[ids],
+    sum_run(x2, k = 99, at = seq_along(x2)[ids], na_pad = TRUE))
+
+  expect_equal(
+    sum_run(x2, k = 100)[ids],
+    sum_run(x2, k = 100, at = seq_along(x2)[ids]))
+
+  expect_equal(
+    sum_run(x2, k = 100, na_pad = TRUE)[ids],
+    sum_run(x2, k = 100, at = seq_along(x2)[ids], na_pad = TRUE))
 })
 
 test_that("       [...|----]---+------->", {
@@ -113,6 +207,24 @@ test_that("       [...|----]---+------->", {
   expect_equal(
     sum_run(x2, k = 5, lag = 3, na_pad = TRUE, na_rm = FALSE),
     runner(x2, k = 5, lag = 3, f = sum, na_pad = TRUE))
+
+
+
+  expect_equal(
+    sum_run(x2, k = 5, lag = 3)[ids],
+    sum_run(x2, k = 5, lag = 3, at = seq_along(x2)[ids]))
+
+  expect_equal(
+    sum_run(x2, k = 5, lag = 3, na_pad = TRUE)[ids],
+    sum_run(x2, k = 5, lag = 3, at = seq_along(x2)[ids], na_pad = TRUE))
+
+  expect_equal(
+    sum_run(x2, k = 5, lag = 3, na_rm = FALSE)[ids],
+    sum_run(x2, k = 5, lag = 3, at = seq_along(x2)[ids], na_rm = FALSE))
+
+  expect_equal(
+    sum_run(x2, k = 5, lag = 3, na_pad = TRUE, na_rm = FALSE)[ids],
+    sum_run(x2, k = 5, lag = 3, at = seq_along(x2)[ids], na_pad = TRUE, na_rm = FALSE))
 })
 
 test_that("       |-----[--+---]--->", {
@@ -131,6 +243,24 @@ test_that("       |-----[--+---]--->", {
   expect_equal(
     sum_run(x2, k = 5, lag = -3, na_pad = TRUE, na_rm = FALSE),
     runner(x2, k = 5, lag = -3, f = sum, na_pad = TRUE))
+
+
+
+  expect_equal(
+    sum_run(x2, k = 5, lag = -3)[ids],
+    sum_run(x2, k = 5, lag = -3, at = seq_along(x2)[ids]))
+
+  expect_equal(
+    sum_run(x2, k = 5, lag = -3, na_pad = TRUE)[ids],
+    sum_run(x2, k = 5, lag = -3, at = seq_along(x2)[ids], na_pad = TRUE))
+
+  expect_equal(
+    sum_run(x2, k = 5, lag = -3, na_rm = FALSE)[ids],
+    sum_run(x2, k = 5, lag = -3, at = seq_along(x2)[ids], na_rm = FALSE))
+
+  expect_equal(
+    sum_run(x2, k = 5, lag = -3, na_pad = TRUE, na_rm = FALSE)[ids],
+    sum_run(x2, k = 5, lag = -3, at = seq_along(x2)[ids], na_pad = TRUE, na_rm = FALSE))
 })
 
 test_that("       |--------+-[---]->", {
@@ -142,6 +272,16 @@ test_that("       |--------+-[---]->", {
     sum_run(x2, k = 5, lag = -7, na_pad = TRUE),
     runner(x2, k = 5, lag = -7, f = sum2, na_pad = TRUE))
 
+
+
+  expect_equal(
+    sum_run(x2, k = 5, lag = -7)[ids],
+    sum_run(x2, k = 5, lag = -7, at = seq_along(x2)[ids]))
+
+  expect_equal(
+    sum_run(x2, k = 5, lag = -7, na_pad = TRUE)[ids],
+    sum_run(x2, k = 5, lag = -7, at = seq_along(x2)[ids], na_pad = TRUE))
+
 })
 
 test_that("       |--------+[]----->", {
@@ -152,6 +292,16 @@ test_that("       |--------+[]----->", {
   expect_equal(
     sum_run(x2, k = 1, lag = -1, na_pad = TRUE),
     runner(x2, k = 1, lag = -1, f = sum2, na_pad = TRUE))
+
+
+
+  expect_equal(
+    sum_run(x2, k = 1, lag = -1)[ids],
+    sum_run(x2, k = 1, lag = -1, at = seq_along(x2)[ids]))
+
+  expect_equal(
+    sum_run(x2, k = 1, lag = -1, na_pad = TRUE)[ids],
+    sum_run(x2, k = 1, lag = -1, at = seq_along(x2)[ids], na_pad = TRUE))
 })
 
 test_that("       |------[]+------->", {
@@ -162,6 +312,16 @@ test_that("       |------[]+------->", {
   expect_equal(
     sum_run(x2, k = 1, lag = 1, na_pad = TRUE),
     runner(x2, k = 1, lag = 1, f = sum2, na_pad = TRUE))
+
+
+
+  expect_equal(
+    sum_run(x2, k = 1, lag = 1)[ids],
+    sum_run(x2, k = 1, lag = 1, at = seq_along(x2)[ids]))
+
+  expect_equal(
+    sum_run(x2, k = 1, lag = 1, na_pad = TRUE)[ids],
+    sum_run(x2, k = 1, lag = 1, at = seq_along(x2)[ids], na_pad = TRUE))
 })
 
 test_that("various", {
@@ -189,7 +349,6 @@ test_that("various", {
   expect_equal(
     sum_run(x2, k = k, lag = lag, na_pad = TRUE),
     runner(x2, k = k, lag = lag, f = sum2, na_pad = TRUE))
-
 })
 
 test_that("date window", {
@@ -286,15 +445,3 @@ test_that("date window", {
     sum_run(x2, k = 4, lag = lag, idx = idx, na_pad = TRUE),
     runner(x2, k = 4, lag = lag, idx = idx, f = sum2, na_pad = TRUE))
 })
-
-
-test_that("Errors", {
-  expect_error(sum_run(x1, k = (1:999)), "length of k and length of x differs")
-  expect_error(sum_run(x1, k = c(NA, k[-1])), "Function doesn't accept NA values in k vector")
-
-  expect_error(sum_run(x1, lag = (1:99)), "length of lag and length of x differs")
-  expect_error(sum_run(x1, lag = c(NA, lag[-1])), "Function doesn't accept NA values in lag vector")
-
-  expect_error(sum_run(x1, idx = (1:99)), "length of idx and length of x differs")
-  expect_error(sum_run(x1, idx = c(NA, 1:99)), "Function doesn't accept NA values in idx vector")
-})
